[hamradio-commits] [gnss-sdr] 54/80: Fix Galileo MSM message numbers

Carles Fernandez carles_fernandez-guest at moszumanska.debian.org
Sun May 15 20:11:57 UTC 2016


This is an automated email from the git hooks/post-receive script.

carles_fernandez-guest pushed a commit to branch upstream
in repository gnss-sdr.

commit af56520798c91b1fbad1a969ef08ec1096e94acd
Author: Carles Fernandez <carles.fernandez at gmail.com>
Date:   Mon May 9 19:24:29 2016 +0200

    Fix Galileo MSM message numbers
---
 src/algorithms/PVT/adapters/galileo_e1_pvt.cc           | 2 +-
 src/algorithms/PVT/gnuradio_blocks/galileo_e1_pvt_cc.cc | 4 ++--
 2 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/src/algorithms/PVT/adapters/galileo_e1_pvt.cc b/src/algorithms/PVT/adapters/galileo_e1_pvt.cc
index 72b2bb4..e2c75df 100644
--- a/src/algorithms/PVT/adapters/galileo_e1_pvt.cc
+++ b/src/algorithms/PVT/adapters/galileo_e1_pvt.cc
@@ -83,7 +83,7 @@ GalileoE1Pvt::GalileoE1Pvt(ConfigurationInterface* configuration,
     int rtcm_MSM_rate_ms = boost::math::lcm(configuration->property(role + ".rtcm_MSM_rate_ms", 1000), output_rate_ms);
     std::map<int,int> rtcm_msg_rate_ms;
     rtcm_msg_rate_ms[1045] = rtcm_MT1045_rate_ms;
-    for (int k = 1071; k < 1078; k++) // All GPS MSM
+    for (int k = 1091; k < 1098; k++) // All Galileo MSM
         {
             rtcm_msg_rate_ms[k] = rtcm_MSM_rate_ms;
         }
diff --git a/src/algorithms/PVT/gnuradio_blocks/galileo_e1_pvt_cc.cc b/src/algorithms/PVT/gnuradio_blocks/galileo_e1_pvt_cc.cc
index cfb4558..a9717e5 100644
--- a/src/algorithms/PVT/gnuradio_blocks/galileo_e1_pvt_cc.cc
+++ b/src/algorithms/PVT/gnuradio_blocks/galileo_e1_pvt_cc.cc
@@ -152,9 +152,9 @@ galileo_e1_pvt_cc::galileo_e1_pvt_cc(unsigned int nchannels, bool dump, std::str
         {
             d_rtcm_MT1045_rate_ms = boost::math::lcm(5000, d_output_rate_ms);  // default value if not set
         }
-    if(rtcm_msg_rate_ms.find(1071) != rtcm_msg_rate_ms.end()) // whatever between 1071 and 1077
+    if(rtcm_msg_rate_ms.find(1091) != rtcm_msg_rate_ms.end()) // whatever between 1091 and 1097
         {
-            d_rtcm_MSM_rate_ms = rtcm_msg_rate_ms[1071];
+            d_rtcm_MSM_rate_ms = rtcm_msg_rate_ms[1091];
         }
     else
         {

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-hamradio/gnss-sdr.git



More information about the pkg-hamradio-commits mailing list